==> derby-0.0.8.tgz: package/lib/modelHelper.js <==
var EventDispatcher;
EventDispatcher = require('./EventDispatcher');
exports.init = function(model, dom, view) {
  var event, events, get, _fn, _fn2, _i, _j, _len, _len2, _ref, _ref2;
  get = model.get;
  events = model.__events = new EventDispatcher({
    onTrigger: function(path, listener, value, type, local) {
      var id, method, oldPath, partial, property;
      oldPath = listener[0], id = listener[1], method = listener[2], property = listener[3], partial = listener[4];
      if (!(oldPath === path || get(oldPath) === get(path))) {
        return false;
      }
      if (partial === '$inv') {
        value = !value;
      } else if (partial) {
        value = view.get(partial, value, null, null, oldPath);
      }
      return dom.update(id, method, property, value, type, local);
    },
    onBind: function(path, listener) {
      return listener.unshift(path);
    }
  });
  if (!dom) {
    return model;
  }
  _ref = ['set', 'push'];
  _fn = function(event) {
    return model.on(event, function(_arg, local) {
      var path, value;
      path = _arg[0], value = _arg[1];
      return events.trigger(path, value, event, local);
    });
  };
  for (_i = 0, _len = _ref.length; _i < _len; _i++) {
    event = _ref[_i];
    _fn(event);
  }
  _ref2 = ['connected', 'canConnect'];
  _fn2 = function(event) {
    return model.on(event, function(value) {
      return events.trigger(event, value);
    });
  };
  for (_j = 0, _len2 = _ref2.length; _j < _len2; _j++) {
    event = _ref2[_j];
    _fn2(event);
  }
  return model;
};

==> derby-0.0.9.tgz: package/lib/modelHelper.js <==
var EventDispatcher;
EventDispatcher = require('./EventDispatcher');
exports.init = function(model, dom, view) {
  var event, events, onBind, _fn, _fn2, _i, _j, _len, _len2, _ref, _ref2;
  onBind = function(path, listener) {
    return listener.unshift(path);
  };
  if (!dom) {
    model.__events = new EventDispatcher({
      onBind: onBind
    });
    return model;
  }
  events = model.__events = new EventDispatcher({
    onBind: onBind,
    onTrigger: function(path, listener, value, type, local) {
      var id, method, oldPath, partial, property;
      oldPath = listener[0], id = listener[1], method = listener[2], property = listener[3], partial = listener[4];
      if (!(oldPath === path || model.get(oldPath) === model.get(path))) {
        return false;
      }
      if (partial === '$inv') {
        value = !value;
      } else if (partial) {
        if (type === 'push') {
          oldPath += '.' + (model.get(path).length - 1);
        }
        value = view.get(partial, value, null, null, oldPath);
      }
      return dom.update(id, method, property, value, type, local);
    }
  });
  _ref = ['set', 'push'];
  _fn = function(event) {
    return model.on(event, function(_arg, local) {
      var path, value;
      path = _arg[0], value = _arg[1];
      return events.trigger(path, value, event, local);
    });
  };
  for (_i = 0, _len = _ref.length; _i < _len; _i++) {
    event = _ref[_i];
    _fn(event);
  }
  _ref2 = ['connected', 'canConnect'];
  _fn2 = function(event) {
    return model.on(event, function(value) {
      return events.trigger(event, value);
    });
  };
  for (_j = 0, _len2 = _ref2.length; _j < _len2; _j++) {
    event = _ref2[_j];
    _fn2(event);
  }
  return model;
};
